@@ -58,7 +58,9 @@ Great! in your notebook install the library by running:
 
 %pip install {self.dbfs_folder.replace("dbfs:/","/dbfs/")}/{self.wheel_file} --force-reinstall --no-deps
 
-If you are dunning spark < 7 use this command:
+If you are running spark < 7 use this command:
+
+!pip install {self.dbfs_folder.replace("dbfs:/","/dbfs/")}/{self.wheel_file} --force-reinstall --no-deps
 
         """
 
@@ -66,7 +68,7 @@ If you are dunning spark < 7 use this command:
         cmd = f"watchmedo shell-command -w -W --interval 3 --patterns='*.py' --ignore-pattern='*build*'" \
               f" --recursive " \
               f"--command='rocket " \
-              f"build_and_deploy " \
+              f"_build_and_deploy " \
               f"{self.project_location} {self.dbfs_folder}' {self.project_location}"
         logging.info(f'watch command: {cmd}')
         print(os.system(cmd))
